@@ -19,3 +19,9 @@ class Column:
     data_type: DataType
     nullable: bool
     default: PrimitiveVal
+
+
+@dataclass(frozen=True)
+class ColumnObj:
+    id_obj: ColumnId
+    column: Column
