@@ -42,6 +42,7 @@ from redshift_client.table.client import (
     TableClient,
 )
 from typing import (
+    Callable,
     Dict,
     FrozenSet,
     Optional,
@@ -158,17 +159,39 @@ class SchemaClient:
     def recreate_cascade(self, schema: SchemaId) -> Cmd[None]:
         return self._recreate(schema, True)
 
-    def migrate(self, source: SchemaId, target: SchemaId) -> Cmd[None]:
+    def _move(
+        self,
+        source: SchemaId,
+        target: SchemaId,
+        move_op: Callable[[TableId, TableId], Cmd[None]],
+    ) -> Cmd[None]:
         _client = TableClient(self._db_client)
         return (
             self.table_ids(source)
             .map(lambda x: from_flist(tuple(x)))
             .bind(
                 lambda p: p.map(
-                    lambda t: _client.overwrite(t, TableId(target, t.name))
+                    lambda t: move_op(t, TableId(target, t.name))
                 ).transform(lambda x: consume(x))
             )
-        )
+        ) + self.delete(source)
+
+    def migrate(self, source: SchemaId, target: SchemaId) -> Cmd[None]:
+        """
+        Moves all tables from `source` to `target` overwriting `target` data.
+        Deletes empty source after success.
+        """
+        _client = TableClient(self._db_client)
+        return self._move(source, target, _client.migrate)
+
+    def move(self, source: SchemaId, target: SchemaId) -> Cmd[None]:
+        """
+        Moves all tables from `source` to `target`.
+        It does not overwrite target data.
+        Deletes empty source after success.
+        """
+        _client = TableClient(self._db_client)
+        return self._move(source, target, _client.move)
 
     def set_policy(self, schema: SchemaId, policy: SchemaPolicy) -> Cmd[None]:
         stm = "ALTER SCHEMA {schema} OWNER TO {owner}"
