@@ -351,9 +351,9 @@ class TableClient:
         return self.move_data(source, target)
 
     def move(self, source: TableId, target: TableId) -> Cmd[None]:
-        return self.move_data(source, target) + self.delete_cascade(source)
+        return self.move_data(source, target) + self.delete(source)
 
-    def overwrite(self, source: TableId, target: TableId) -> Cmd[None]:
+    def migrate(self, source: TableId, target: TableId) -> Cmd[None]:
         nothing = Cmd.from_cmd(lambda: None)
         recreate = self.exist(target).bind(
             lambda b: self.delete_cascade(target)
@@ -362,3 +362,7 @@ class TableClient:
             else nothing
         )
         return recreate + self.move(source, target)
+
+    @deprecated(reason="Renamed method, use 'migrate' instead")  # type: ignore[misc]
+    def overwrite(self, source: TableId, target: TableId) -> Cmd[None]:
+        return self.migrate(source, target)
